// Include file for PIC16F767 registers

#byte TRISA = 0x85
#byte PORTA = 0x05
#bit RA0 = PORTA.0
#bit RA1 = PORTA.1
#bit RA2 = PORTA.2
#bit RA3 = PORTA.3
#bit RA4 = PORTA.4
#bit RA5 = PORTA.5
#bit RA6 = PORTA.6
#bit RA7 = PORTA.7

#byte TRISB = 0x86
#byte PORTB = 0x06
#bit RB0 = PORTB.0
#bit RB1 = PORTB.1
#bit RB2 = PORTB.2
#bit RB3 = PORTB.3
#bit RB4 = PORTB.4
#bit RB5 = PORTB.5
#bit RB6 = PORTB.6
#bit RB7 = PORTB.7

#byte TRISC = 0x87
#byte PORTC = 0x87
#bit RC0 = PORTC.0
#bit RC1 = PORTC.1
#bit RC2 = PORTC.2
#bit RC3 = PORTC.3
#bit RC4 = PORTC.4
#bit RC5 = PORTC.5
#bit RC6 = PORTC.6
#bit RC7 = PORTC.7

#byte TRISE = 0x89
#byte PORTE = 0x89
#bit RE0 = PORTE.0
#bit RE1 = PORTE.1
#bit RE2 = PORTE.2
#bit RE3 = PORTE.3
#bit RE4 = PORTE.4
#bit RE5 = PORTE.5
#bit RE6 = PORTE.6
#bit RE7 = PORTE.7

// INTERRUPT CONTROL REGISTER
#byte INTCON   =  0x0B
#bit  GIE      = INTCON.7 // Global Interrupt Enable bit
#bit  PEIE     = INTCON.6 // Peripheral Interrupt Enable bit
#bit  TMR0IE   = INTCON.5 // TMR0 Overflow Interrupt Enable bit
#bit  INT0IE   = INTCON.4 // RB0/INT External Interrupt Enable bit
#bit  RBIE     = INTCON.3 // RB Port Change Interrupt Enable bit
#bit  TMR0IF   = INTCON.2 // TMR0 Overflow Interrupt Flag bit
#bit  INT0IF   = INTCON.1 // RB0/INT External Interrupt Flag bit
#bit  RBIF     = INTCON.0 // RB Port Change Interrupt Flag bit

// PERIPHERAL INTERRUPT ENABLE REGISTER 1
#byte PIE1     = 0x8C
#bit  PSPIE    = PIE1.7 // Parallel Slave Port Read/Write Interrupt Enable bit
#bit  ADIE     = PIE1.6 // A/D Converter Interrupt Enable bit
#bit  RCIE     = PIE1.5 // AUSART Receive Interrupt Enable bit
#bit  TXIE     = PIE1.4 // AUSART Transmit Interrupt Enable bit
#bit  SSPIE    = PIE1.3 // Synchronous Serial Port Interrupt Enable bit
#bit  CCP1IE   = PIE1.2 // CCP1 Interrupt Enable bit
#bit  TMR2IE   = PIE1.1 // TMR2 to PR2 Match Interrupt Enable bit
#bit  TMR1IE   = PIE1.0 // TMR1 Overflow Interrupt Enable bit

// PERIPHERAL INTERRUPT REQUEST (FLAG) REGISTER 1
#byte PIR1     = 0x0C
#bit  PSPIF    = PIR1.7 // Parallel Slave Port Read/Write Interrupt Flag bit
#bit  ADIF     = PIR1.6 // A/D Converter Interrupt Flag bit
#bit  RCIF     = PIR1.5 // AUSART Receive Interrupt Flag bit
#bit  TXIF     = PIR1.4 // AUSART Transmit Interrupt Flag bit
#bit  SSPIF    = PIR1.3 // Synchronous Serial Port (SSP) Interrupt Flag bit
#bit  CCP1IF   = PIR1.2 // CCP1 Interrupt Flag bit
#bit  TMR2IF   = PIR1.1 // TMR2 to PR2 Match Interrupt Flag bit
#bit  TMR1IF   = PIR1.0 // TMR1 Overflow Interrupt Flag bit

// PERIPHERAL INTERRUPT ENABLE REGISTER 2
#byte PIE2     = 0x8D
#bit  OSFIE    = PIE2.7 // Oscillator Fail Interrupt Enable bit
#bit  CMIE     = PIE2.6 // Comparator Interrupt Enable bit
#bit  LVDIE    = PIE2.5 // Low-Voltage Detect Interrupt Enable bit
// Bit 4       = Unimplemented: Read as '0'
#bit  BCLIE    = PIE2.3 // Bus Collision Interrupt Enable bit
// Bit 2       = Unimplemented: Read as '0'
#bit  CCP3IE   = PIE2.1 // CCP3 Interrupt Enable bit
#bit  CCP2IE   = PIE2.0 // CCP2 Interrupt Enable bit

// PERIPHERAL INTERRUPT REQUEST (FLAG) REGISTER 2
#byte PIR2     = 0x0D
#bit  OSFIF    = PIR2.7 // Oscillator Fail Interrupt Flag bit
#bit  CMIF     = PIR2.6 // Comparator Interrupt Flag bit
#bit  LVDIF    = PIR2.5 // Low-Voltage Detect Interrupt Flag bit
// Bit 4       = Unimplemented: Read as '0'
#bit  BCLIF    = PIR2.3 // Bus Collision Interrupt Flag bit
// Bit 2       = Unimplemented: Read as '0'
#bit  CCP3IF   = PIR2.1 // CCP3 Interrupt Flag bit
#bit  CCP2IF   = PIR2.0 // CCP2 Interrupt Flag bit

// OSCILLATOR CONTROL REGISTER
#byte OSCCON   = 0x8F
// Bit 7       = Unimplemented: Read as '0'
#bit  IRCF2    = OSCCON.6 // Internal RC Oscillator Frequency Select bits
#bit  IRCF1    = OSCCON.5 // Internal RC Oscillator Frequency Select bits
#bit  IRCF0    = OSCCON.4 // Internal RC Oscillator Frequency Select bits
#bit  OSTS     = OSCCON.3 // Oscillator Start-up Time-out Status bit
#bit  IOFS     = OSCCON.2 // INTOSC Frequency Stable bit
#bit  SCS1     = OSCCON.1 // Oscillator Mode Select bits
#bit  SCS0     = OSCCON.0 // Oscillator Mode Select bits

