#include "RPM_display_for_minimill.h"
#include "16F767_general_registers.h"

#include "16F767_ausart.c"
#include "7-segment_LED_display.c"

void main()
{
   int16 data;
   int8 DigitValue[4];
   int1 ClearZero;
   int8 TimeOut;

   // Setup internal oscillator for 8MHz
   // Not needed because of #FUSES INTRC_IO
   setup_oscillator(OSC_8MHZ|OSC_INTRC);

   // Set pin directions
   set_tris_a(0b00001111);
   set_tris_b(0b11100000);
   set_tris_c(0b10000000);

   // Set startup pin states
   output_a(0xFF);
   output_b(0xFF);
   output_c(0xFF);

   SetupAUSART();

   delay_ms(1500);

WriteToDisp(9, 9);

   while(1)
   {
      // Receive and construct 16-bit number from received bytes
      while(!RCIF); // Wait for receival of the first byte
      if(OERR || FERR) // If overrun or framing error
      {
         if(OERR) // If overrun
         {
            // Disable and enable reception to clear overrun flag bit
            CREN = 0;   // Disable the reception
            CREN = 1;   // Enable the reception
            // Indicate overrun (E0)
            Seg1_E();
            Seg2_0();
         }
         else // Must be framing error
         {
            // Read received data to clear framing error flag bit
            data = RCREG; // Read received data
            // Indicate framing error (E1)
            Seg1_E();
            Seg2_1();
         }
      }
      else
      {
         data = RCREG;
         data <<= 8;
   
         TimeOut = 0;
         while(!RCIF && (TimeOut < 250)) // Wait for receival of the second byte or timeout (2,5ms)
         {
            delay_us(10);
            TimeOut++;
         }
         if(TimeOut < 250) // Not timed out
         {
            if(OERR || FERR) // If overrun or framing error
            {
               if(OERR) // If overrun
               {
                  // Disable and enable reception to clear overrun flag bit
                  CREN = 0;   // Disable the reception
                  CREN = 1;   // Enable the reception
                  // Indicate overrun (E0)
                  Seg1_E();
                  Seg1_0();
               }
               else // Must be framing error
               {
                  // Read received data to clear framing error flag bit
                  data = RCREG; // Read received data
                  // Indicate framing error (E1)
                  Seg1_E();
                  Seg1_1();
               }
            }
            else
            {
               data += RCREG;
               
               // Initialize digits
               DigitValue[0] = 0;
               DigitValue[1] = 0;
               DigitValue[2] = 0;
               DigitValue[3] = 0;
               ClearZero = 1;
         
               // Decode digits from received data
               while(data > 9999) // Delete anything above 9999 (5 digits)
               {
                  data -= 10000;
               }
               
               while(data > 999)
               {
                  data -= 1000;
                  DigitValue[0]++;
                  ClearZero = 0;
               }
               if((DigitValue[0] == 0) && (ClearZero))
               {
                  DigitValue[0] = 10; // Set digit to something out of range
               }
               
               while(data > 99)
               {
                  data -= 100;
                  DigitValue[1]++;
                  ClearZero = 0;
               }
               if((DigitValue[1] == 0) && (ClearZero))
               {
                  DigitValue[1] = 10; // Set digit to something out of range
               }
               
               while(data > 9)
               {
                  data -= 10;
                  DigitValue[2]++;
                  ClearZero = 0;
               }
               if((DigitValue[2] == 0) && (ClearZero))
               {
                  DigitValue[2] = 10; // Set digit to something out of range
               }

               DigitValue[3] = data;
         
               // Digits for 1's and 10's (PIC1)
//               WriteToDisp(DigitValue[2], DigitValue[3]);
         
               // Digits for 100's and 1000's (PIC2)
               WriteToDisp(DigitValue[0], DigitValue[1]);
            }
         }
      }
   }
}
